Package: GlarmaVarSel
Type: Package
Title: Variable Selection in Sparse GLARMA Models
Version: 1.0
Date: 2021-09-15
Author: M. Gomtsyan, C. Levy-Leduc, S. Ouadah, L. Sansonnet
Maintainer: Marina Gomtsyan <marina.gomtsyan@agroparistech.fr>
Description: Performs variable selection in high-dimensional sparse GLARMA models. For further details we refer the reader to the paper Gomtsyan et al. (2020), <arXiv:2007.08623v1>.
License: GPL-2
Depends: R (>= 3.5.0), Matrix, glmnet, stats, ggplot2
VignetteBuilder: knitr
Suggests: knitr, markdown, formatR, doMC
NeedsCompilation: no
Packaged: 2021-09-15 15:26:37 UTC; marina
Repository: CRAN
Date/Publication: 2021-09-16 07:40:02 UTC
